@@ -119,11 +119,8 @@ virDomainObjListFindByID(virDomainObjList *doms,
     virObjectRWUnlock(doms);
     if (obj) {
         virObjectLock(obj);
-        if (obj->removing) {
-            virObjectUnlock(obj);
-            virObjectUnref(obj);
-            obj = NULL;
-        }
+        if (obj->removing)
+            virDomainObjEndAPI(&obj);
     }
 
     return obj;
@@ -165,11 +162,8 @@ virDomainObjListFindByUUID(virDomainObjList *doms,
     obj = virDomainObjListFindByUUIDLocked(doms, uuid);
     virObjectRWUnlock(doms);
 
-    if (obj && obj->removing) {
-        virObjectUnlock(obj);
-        virObjectUnref(obj);
-        obj = NULL;
-    }
+    if (obj && obj->removing)
+        virDomainObjEndAPI(&obj);
 
     return obj;
 }
@@ -208,11 +202,8 @@ virDomainObjListFindByName(virDomainObjList *doms,
     obj = virDomainObjListFindByNameLocked(doms, name);
     virObjectRWUnlock(doms);
 
-    if (obj && obj->removing) {
-        virObjectUnlock(obj);
-        virObjectUnref(obj);
-        obj = NULL;
-    }
+    if (obj && obj->removing)
+        virDomainObjEndAPI(&obj);
 
     return obj;
 }
@@ -266,13 +257,17 @@ virDomainObjListAddObjLocked(virDomainObjList *doms,
  * the @def being added is assumed to represent a
  * live config, not a future inactive config
  *
+ * Upon successful return the virDomain object is the owner of
+ * @def and callers should use @vm->def if they need to access
+ * the definition as @def is set to NULL.
+ *
  * The returned @vm from this function will be locked and ref
  * counted. The caller is expected to use virDomainObjEndAPI
  * when it completes usage.
  */
 static virDomainObj *
 virDomainObjListAddLocked(virDomainObjList *doms,
-                          virDomainDef *def,
+                          virDomainDef **def,
                           virDomainXMLOption *xmlopt,
                           unsigned int flags,
                           virDomainDef **oldDef)
@@ -284,13 +279,13 @@ virDomainObjListAddLocked(virDomainObjList *doms,
         *oldDef = NULL;
 
     /* See if a VM with matching UUID already exists */
-    if ((vm = virDomainObjListFindByUUIDLocked(doms, def->uuid))) {
+    if ((vm = virDomainObjListFindByUUIDLocked(doms, (*def)->uuid))) {
         if (vm->removing) {
             virReportError(VIR_ERR_OPERATION_FAILED,
                            _("domain '%s' is already being removed"),
                            vm->def->name);
             goto error;
-        } else if (STRNEQ(vm->def->name, def->name)) {
+        } else if (STRNEQ(vm->def->name, (*def)->name)) {
             /* UUID matches, but if names don't match, refuse it */
             virUUIDFormat(vm->def->uuid, uuidstr);
             virReportError(VIR_ERR_OPERATION_FAILED,
@@ -321,20 +316,20 @@ virDomainObjListAddLocked(virDomainObjList *doms,
                               oldDef);
     } else {
         /* UUID does not match, but if a name matches, refuse it */
-        if ((vm = virDomainObjListFindByNameLocked(doms, def->name))) {
+        if ((vm = virDomainObjListFindByNameLocked(doms, (*def)->name))) {
             virUUIDFormat(vm->def->uuid, uuidstr);
             virReportError(VIR_ERR_OPERATION_FAILED,
                            _("domain '%s' already exists with uuid %s"),
-                           def->name, uuidstr);
+                           (*def)->name, uuidstr);
             goto error;
         }
 
         if (!(vm = virDomainObjNew(xmlopt)))
             goto error;
-        vm->def = def;
+        vm->def = g_steal_pointer(def);
 
         if (virDomainObjListAddObjLocked(doms, vm) < 0) {
-            vm->def = NULL;
+            *def = g_steal_pointer(&vm->def);
             goto error;
         }
     }
@@ -349,7 +344,7 @@ virDomainObjListAddLocked(virDomainObjList *doms,
 
 virDomainObj *
 virDomainObjListAdd(virDomainObjList *doms,
-                    virDomainDef *def,
+                    virDomainDef **def,
                     virDomainXMLOption *xmlopt,
                     unsigned int flags,
                     virDomainDef **oldDef)
@@ -507,7 +502,7 @@ virDomainObjListLoadConfig(virDomainObjList *doms,
     if ((autostart = virFileLinkPointsTo(autostartLink, configFile)) < 0)
         goto error;
 
-    if (!(dom = virDomainObjListAddLocked(doms, def, xmlopt, 0, &oldDef)))
+    if (!(dom = virDomainObjListAddLocked(doms, &def, xmlopt, 0, &oldDef)))
         goto error;
 
     dom->autostart = autostart;
@@ -953,8 +948,7 @@ virDomainObjListFilter(virDomainObj ***list,
         if (vm->removing ||
             (filter && !filter(conn, vm->def)) ||
             !virDomainObjMatchFilter(vm, flags)) {
-            virObjectUnlock(vm);
-            virObjectUnref(vm);
+            virDomainObjEndAPI(&vm);
             VIR_DELETE_ELEMENT(*list, i, *nvms);
             continue;
         }
