@@ -548,13 +548,12 @@ libxlDomainMigrationDstPrepareTunnel3(virConnectPtr dconn,
                                        &mig, &xmlout, &taint_hook) < 0)
         goto error;
 
-    if (!(vm = virDomainObjListAdd(driver->domains, *def,
+    if (!(vm = virDomainObjListAdd(driver->domains, def,
                                    driver->xmlopt,
                                    VIR_DOMAIN_OBJ_LIST_ADD_LIVE |
                                    VIR_DOMAIN_OBJ_LIST_ADD_CHECK_LIVE,
                                    NULL)))
         goto error;
-    *def = NULL;
 
     /*
      * Unless an error is encountered in this function, the job will
@@ -658,13 +657,12 @@ libxlDomainMigrationDstPrepare(virConnectPtr dconn,
                                        &mig, &xmlout, &taint_hook) < 0)
         goto error;
 
-    if (!(vm = virDomainObjListAdd(driver->domains, *def,
+    if (!(vm = virDomainObjListAdd(driver->domains, def,
                                    driver->xmlopt,
                                    VIR_DOMAIN_OBJ_LIST_ADD_LIVE |
                                    VIR_DOMAIN_OBJ_LIST_ADD_CHECK_LIVE,
                                    NULL)))
         goto error;
-    *def = NULL;
 
     /*
      * Unless an error is encountered in this function, the job will
@@ -902,7 +900,7 @@ libxlMigrationSrcStartTunnel(libxlDriverPrivate *driver,
     tc->dataFD[0] = -1;
     tc->dataFD[1] = -1;
     if (virPipe(tc->dataFD) < 0)
-        goto out;
+        return -1;
 
     arg = &tc->tmThread;
     /* Read from pipe */
@@ -915,7 +913,7 @@ libxlMigrationSrcStartTunnel(libxlDriverPrivate *driver,
                             name, false, arg) < 0) {
         virReportError(errno, "%s",
                        _("Unable to create tunnel migration thread"));
-        goto out;
+        return -1;
     }
 
     virObjectUnlock(vm);
@@ -923,7 +921,6 @@ libxlMigrationSrcStartTunnel(libxlDriverPrivate *driver,
     ret = libxlDoMigrateSrcSend(driver, vm, flags, tc->dataFD[1]);
     virObjectLock(vm);
 
- out:
     /* libxlMigrationSrcStopTunnel will be called in libxlDoMigrateSrcP2P
      * to free all resources for us.
      */
