@@ -336,18 +336,15 @@ static int
 qemuSetupTPMCgroup(virDomainObj *vm,
                    virDomainTPMDef *dev)
 {
-    int ret = 0;
-
     switch (dev->type) {
     case VIR_DOMAIN_TPM_TYPE_PASSTHROUGH:
-        ret = qemuSetupChrSourceCgroup(vm, &dev->data.passthrough.source);
-        break;
+        return qemuSetupChrSourceCgroup(vm, dev->data.passthrough.source);
     case VIR_DOMAIN_TPM_TYPE_EMULATOR:
     case VIR_DOMAIN_TPM_TYPE_LAST:
         break;
     }
 
-    return ret;
+    return 0;
 }
 
 
@@ -608,9 +605,8 @@ qemuSetupBlkioCgroup(virDomainObj *vm)
             virReportError(VIR_ERR_CONFIG_UNSUPPORTED, "%s",
                            _("Block I/O tuning is not available on this host"));
             return -1;
-        } else {
-            return 0;
         }
+        return 0;
     }
 
     return virDomainCgroupSetupBlkio(priv->cgroup, vm->def->blkio);
@@ -629,9 +625,8 @@ qemuSetupMemoryCgroup(virDomainObj *vm)
             virReportError(VIR_ERR_CONFIG_UNSUPPORTED, "%s",
                            _("Memory cgroup is not available on this host"));
             return -1;
-        } else {
-            return 0;
         }
+        return 0;
     }
 
     return virDomainCgroupSetupMemtune(priv->cgroup, vm->def->mem);
@@ -891,9 +886,8 @@ qemuSetupCpuCgroup(virDomainObj *vm)
            virReportError(VIR_ERR_CONFIG_UNSUPPORTED, "%s",
                           _("CPU tuning is not available on this host"));
            return -1;
-       } else {
-           return 0;
        }
+       return 0;
     }
 
     if (vm->def->cputune.sharesSpecified) {
