@@ -693,6 +693,7 @@ AppArmorSetMemoryLabel(virSecurityManager *mgr,
         return reload_profile(mgr, def, mem->nvdimmPath, true);
     case VIR_DOMAIN_MEMORY_MODEL_NONE:
     case VIR_DOMAIN_MEMORY_MODEL_DIMM:
+    case VIR_DOMAIN_MEMORY_MODEL_VIRTIO_MEM:
     case VIR_DOMAIN_MEMORY_MODEL_LAST:
         break;
     }
@@ -1168,10 +1169,7 @@ static char *
 AppArmorGetMountOptions(virSecurityManager *mgr G_GNUC_UNUSED,
                         virDomainDef *vm G_GNUC_UNUSED)
 {
-    char *opts;
-
-    opts = g_strdup("");
-    return opts;
+    return g_strdup("");
 }
 
 static const char *
