@@ -567,34 +567,33 @@ verify_xpath_context(xmlXPathContextPtr ctxt)
 static int
 caps_mockup(vahControl * ctl, const char *xmlStr)
 {
-    int rc = -1;
-    xmlDocPtr xml = NULL;
-    xmlXPathContextPtr ctxt = NULL;
+    g_autoptr(xmlDoc) xml = NULL;
+    g_autoptr(xmlXPathContext) ctxt = NULL;
     char *arch;
 
     if (!(xml = virXMLParseStringCtxt(xmlStr, _("(domain_definition)"),
                                       &ctxt))) {
-        goto cleanup;
+        return -1;
     }
 
     if (!virXMLNodeNameEqual(ctxt->node, "domain")) {
         vah_error(NULL, 0, _("unexpected root element, expecting <domain>"));
-        goto cleanup;
+        return -1;
     }
 
     /* Quick sanity check for some required elements */
     if (verify_xpath_context(ctxt) != 0)
-        goto cleanup;
+        return -1;
 
     ctl->virtType = virXPathString("string(./@type)", ctxt);
     if (!ctl->virtType) {
         vah_error(ctl, 0, _("domain type is not defined"));
-        goto cleanup;
+        return -1;
     }
     ctl->os = virXPathString("string(./os/type[1])", ctxt);
     if (!ctl->os) {
         vah_error(ctl, 0, _("os.type is not defined"));
-        goto cleanup;
+        return -1;
     }
     arch = virXPathString("string(./os/type[1]/@arch)", ctxt);
     if (!arch) {
@@ -604,13 +603,7 @@ caps_mockup(vahControl * ctl, const char *xmlStr)
         VIR_FREE(arch);
     }
 
-    rc = 0;
-
- cleanup:
-    xmlFreeDoc(xml);
-    xmlXPathFreeContext(ctxt);
-
-    return rc;
+    return 0;
 }
 
 virDomainDefParserConfig virAAHelperDomainDefParserConfig = {
@@ -649,31 +642,16 @@ get_definition(vahControl * ctl, const char *xmlStr)
         return -1;
     }
 
-    if ((guest = virCapabilitiesAddGuest(ctl->caps,
-                                         ostype,
-                                         ctl->arch,
-                                         NULL,
-                                         NULL,
-                                         0,
-                                         NULL)) == NULL) {
-        vah_error(ctl, 0, _("could not allocate memory"));
-        return -1;
-    }
+    guest = virCapabilitiesAddGuest(ctl->caps, ostype, ctl->arch,
+                                    NULL, NULL, 0, NULL);
 
     if ((virtType = virDomainVirtTypeFromString(ctl->virtType)) < 0) {
         vah_error(ctl, 0, _("unknown virtualization type"));
         return -1;
     }
 
-    if (virCapabilitiesAddGuestDomain(guest,
-                                      virtType,
-                                      NULL,
-                                      NULL,
-                                      0,
-                                      NULL) == NULL) {
-        vah_error(ctl, 0, _("could not allocate memory"));
-        return -1;
-    }
+    virCapabilitiesAddGuestDomain(guest, virtType,
+                                  NULL, NULL, 0, NULL);
 
     ctl->def = virDomainDefParseString(xmlStr,
                                        ctl->xmlopt, NULL,
@@ -1194,8 +1172,8 @@ get_files(vahControl * ctl)
          * When the server path is enabled, use it - otherwise fallback to
          * model dependent defaults. */
         if (shmem->server.enabled &&
-            shmem->server.chr.data.nix.path) {
-                if (vah_add_file(&buf, shmem->server.chr.data.nix.path,
+            shmem->server.chr->data.nix.path) {
+                if (vah_add_file(&buf, shmem->server.chr->data.nix.path,
                         "rw") != 0)
                     goto cleanup;
         } else {
@@ -1459,6 +1437,8 @@ main(int argc, char **argv)
     int rc = -1;
     char *profile = NULL;
     char *include_file = NULL;
+    off_t size;
+    bool purged = 0;
 
     if (virGettextInitialize() < 0 ||
         virErrorInitialize() < 0) {
@@ -1506,6 +1486,22 @@ main(int argc, char **argv)
         if (ctl->cmd == 'c' && virFileExists(profile))
             vah_error(ctl, 1, _("profile exists"));
 
+        /*
+         * Rare cases can leave corrupted empty files behind breaking
+         * the guest. An empty file is never correct as virt-aa-helper
+         * would at least add the basic rules, therefore clean this up
+         * for a proper refresh.
+         */
+        if (virFileExists(profile)) {
+                size = virFileLength(profile, -1);
+                if (size == 0) {
+                        vah_warning(_("Profile of 0 size detected, will attempt to remove it"));
+                        if ((rc = parserRemove(ctl->uuid) != 0))
+                                vah_error(ctl, 1, _("could not remove profile"));
+                        unlink(profile);
+                        purged = true;
+                }
+        }
         if (ctl->append && ctl->newfile) {
             if (vah_add_file(&buf, ctl->newfile, "rwk") != 0)
                 goto cleanup;
@@ -1545,7 +1541,7 @@ main(int argc, char **argv)
 
 
         /* create the profile from TEMPLATE */
-        if (ctl->cmd == 'c') {
+        if (ctl->cmd == 'c' || purged) {
             char *tmp = NULL;
             tmp = g_strdup_printf("  #include <libvirt/%s.files>\n", ctl->uuid);
 
