@@ -103,7 +103,7 @@ virJSONValueGetType(const virJSONValue *value)
 
 /**
  * virJSONValueObjectAddVArgs:
- * @obj: JSON object to add the values to
+ * @objptr: pointer to a pointer to a JSON object to add the values to
  * @args: a key-value argument pairs, terminated by NULL
  *
  * Adds the key-value pairs supplied as variable argument list to @obj.
@@ -152,13 +152,18 @@ virJSONValueGetType(const virJSONValue *value)
  * in case of no error but nothing was filled.
  */
 int
-virJSONValueObjectAddVArgs(virJSONValue *obj,
+virJSONValueObjectAddVArgs(virJSONValue **objptr,
                            va_list args)
 {
+    g_autoptr(virJSONValue) newobj = NULL;
+    virJSONValue *obj = *objptr;
     char type;
     char *key;
     int rc;
 
+    if (obj == NULL)
+        newobj = obj = virJSONValueNewObject();
+
     while ((key = va_arg(args, char *)) != NULL) {
 
         if (strlen(key) < 3 || key[1] != ':') {
@@ -343,50 +348,21 @@ virJSONValueObjectAddVArgs(virJSONValue *obj,
     if (virJSONValueObjectKeysNumber(obj) == 0)
         return 0;
 
+    if (newobj)
+        *objptr = g_steal_pointer(&newobj);
+
     return 1;
 }
 
 
 int
-virJSONValueObjectAdd(virJSONValue *obj, ...)
+virJSONValueObjectAdd(virJSONValue **objptr, ...)
 {
     va_list args;
     int ret;
 
-    va_start(args, obj);
-    ret = virJSONValueObjectAddVArgs(obj, args);
-    va_end(args);
-
-    return ret;
-}
-
-
-int
-virJSONValueObjectCreateVArgs(virJSONValue **obj,
-                              va_list args)
-{
-    int ret;
-
-    *obj = virJSONValueNewObject();
-
-    /* free the object on error, or if no value objects were added */
-    if ((ret = virJSONValueObjectAddVArgs(*obj, args)) <= 0) {
-        virJSONValueFree(*obj);
-        *obj = NULL;
-    }
-
-    return ret;
-}
-
-
-int
-virJSONValueObjectCreate(virJSONValue **obj, ...)
-{
-    va_list args;
-    int ret;
-
-    va_start(args, obj);
-    ret = virJSONValueObjectCreateVArgs(obj, args);
+    va_start(args, objptr);
+    ret = virJSONValueObjectAddVArgs(objptr, args);
     va_end(args);
 
     return ret;
