@@ -44,13 +44,9 @@ void virJSONValueHashFree(void *opaque);
 
 virJSONType virJSONValueGetType(const virJSONValue *value);
 
-int virJSONValueObjectCreate(virJSONValue **obj, ...)
+int virJSONValueObjectAdd(virJSONValue **obj, ...)
     ATTRIBUTE_NONNULL(1) G_GNUC_NULL_TERMINATED;
-int virJSONValueObjectCreateVArgs(virJSONValue **obj, va_list args)
-    ATTRIBUTE_NONNULL(1);
-int virJSONValueObjectAdd(virJSONValue *obj, ...)
-    ATTRIBUTE_NONNULL(1) G_GNUC_NULL_TERMINATED;
-int virJSONValueObjectAddVArgs(virJSONValue *obj, va_list args)
+int virJSONValueObjectAddVArgs(virJSONValue **objptr, va_list args)
     ATTRIBUTE_NONNULL(1);
 
 
