@@ -35,7 +35,7 @@
 # include <sys/time.h>
 # include <sys/resource.h>
 #endif
-#if WITH_SCHED_SETSCHEDULER
+#if WITH_SCHED_H
 # include <sched.h>
 #endif
 
@@ -480,7 +480,7 @@ int virProcessKillPainfully(pid_t pid, bool force)
     return virProcessKillPainfullyDelay(pid, force, 0, false);
 }
 
-#if WITH_SCHED_GETAFFINITY
+#if WITH_DECL_CPU_SET_T
 
 int virProcessSetAffinity(pid_t pid, virBitmap *map, bool quiet)
 {
@@ -626,7 +626,7 @@ virProcessGetAffinity(pid_t pid)
     return ret;
 }
 
-#else /* WITH_SCHED_GETAFFINITY */
+#else /* WITH_DECL_CPU_SET_T */
 
 int virProcessSetAffinity(pid_t pid G_GNUC_UNUSED,
                           virBitmap *map G_GNUC_UNUSED,
@@ -646,7 +646,7 @@ virProcessGetAffinity(pid_t pid G_GNUC_UNUSED)
                          _("Process CPU affinity is not supported on this platform"));
     return NULL;
 }
-#endif /* WITH_SCHED_GETAFFINITY */
+#endif /* WITH_DECL_CPU_SET_T */
 
 
 int virProcessGetPids(pid_t pid, size_t *npids, pid_t **pids)
@@ -1153,56 +1153,22 @@ virProcessSetMaxCoreSize(pid_t pid G_GNUC_UNUSED,
 int virProcessGetStartTime(pid_t pid,
                            unsigned long long *timestamp)
 {
-    char *tmp;
-    int len;
-    g_autofree char *filename = NULL;
-    g_autofree char *buf = NULL;
-    g_auto(GStrv) tokens = NULL;
+    g_auto(GStrv) proc_stat = virProcessGetStat(pid, 0);
+    const char *starttime_str = NULL;
 
-    filename = g_strdup_printf("/proc/%llu/stat", (long long)pid);
-
-    if ((len = virFileReadAll(filename, 1024, &buf)) < 0)
-        return -1;
-
-    /* start time is the token at index 19 after the '(process name)' entry - since only this
-     * field can contain the ')' character, search backwards for this to avoid malicious
-     * processes trying to fool us
-     */
-
-    if (!(tmp = strrchr(buf, ')'))) {
+    if (!proc_stat || g_strv_length(proc_stat) < 22) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
-                       _("Cannot find start time in %s"),
-                       filename);
-        return -1;
-    }
-    tmp += 2; /* skip ') ' */
-    if ((tmp - buf) >= len) {
-        virReportError(VIR_ERR_INTERNAL_ERROR,
-                       _("Cannot find start time in %s"),
-                       filename);
+                       _("Cannot find start time for pid %d"), (int)pid);
         return -1;
     }
 
-    tokens = g_strsplit(tmp, " ", 0);
-
-    if (!tokens ||
-        g_strv_length(tokens) < 20) {
+    starttime_str = proc_stat[VIR_PROCESS_STAT_STARTTIME];
+    if (virStrToLong_ull(starttime_str, NULL, 10, timestamp) < 0) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
-                       _("Cannot find start time in %s"),
-                       filename);
+                       _("Cannot parse start time %s for pid %d"),
+                       starttime_str, (int)pid);
         return -1;
     }
-
-    if (virStrToLong_ull(tokens[19],
-                         NULL,
-                         10,
-                         timestamp) < 0) {
-        virReportError(VIR_ERR_INTERNAL_ERROR,
-                       _("Cannot parse start time %s in %s"),
-                       tokens[19], filename);
-        return -1;
-    }
-
     return 0;
 }
 #elif defined(__FreeBSD__) || defined(__FreeBSD_kernel__)
@@ -1721,3 +1687,80 @@ virProcessSetScheduler(pid_t pid G_GNUC_UNUSED,
 }
 
 #endif /* !WITH_SCHED_SETSCHEDULER */
+
+/*
+ * Get all stat fields for a process based on pid and tid:
+ * - pid == 0 && tid == 0 => /proc/self/stat
+ * - pid != 0 && tid == 0 => /proc/<pid>/stat
+ * - pid == 0 && tid != 0 => /proc/self/task/<tid>/stat
+ * - pid != 0 && tid != 0 => /proc/<pid>/task/<tid>/stat
+ * and return them as array of strings.
+ */
+GStrv
+virProcessGetStat(pid_t pid,
+                  pid_t tid)
+{
+    int len = 10 * 1024;  /* 10kB ought to be enough for everyone */
+    g_autofree char *buf = NULL;
+    g_autofree char *path = NULL;
+    GStrv rest = NULL;
+    GStrv ret = NULL;
+    char *comm = NULL;
+    char *rparen = NULL;
+    size_t nrest = 0;
+
+    if (pid) {
+        if (tid)
+            path = g_strdup_printf("/proc/%d/task/%d/stat", (int)pid, (int)tid);
+        else
+            path = g_strdup_printf("/proc/%d/stat", (int)pid);
+    } else {
+        if (tid)
+            path = g_strdup_printf("/proc/self/task/%d/stat", (int)tid);
+        else
+            path = g_strdup("/proc/self/stat");
+    }
+
+    len = virFileReadAllQuiet(path, len, &buf);
+    if (len < 0)
+        return NULL;
+
+    /* eliminate trailing spaces */
+    while (len > 0 && g_ascii_isspace(buf[--len]))
+           buf[len] = '\0';
+
+    /* Find end of the first field */
+    if (!(comm = strchr(buf, ' ')))
+        return NULL;
+    *comm = '\0';
+
+    /* Check start of the second field (filename of the executable, in
+     * parentheses) */
+    comm++;
+    if (*comm != '(')
+        return NULL;
+    comm++;
+
+    /* Check end of the second field (last closing parenthesis) */
+    rparen = strrchr(comm, ')');
+    if (!rparen)
+        return NULL;
+    *rparen = '\0';
+
+    /* We need to check that the next char is not '\0', but why not just opt in
+     * for the safer way of checking whether it is ' ' (space) instead */
+    if (rparen[1] != ' ')
+        return NULL;
+
+    rest = g_strsplit(rparen + 2, " ", 0);
+    nrest = g_strv_length(rest);
+    ret = g_new0(char *, nrest + 3);
+    ret[0] = g_strdup(buf);
+    ret[1] = g_strdup(comm);
+    memcpy(ret + 2, rest, nrest * sizeof(char *));
+
+    /* Do not use g_strfreev() as individual elements they were moved to @ret. */
+    VIR_FREE(rest);
+
+    return ret;
+}
