@@ -117,6 +117,72 @@ int virProcessSetupPrivateMountNS(void);
 int virProcessSetScheduler(pid_t pid,
                            virProcessSchedPolicy policy,
                            int priority);
+
+GStrv virProcessGetStat(pid_t pid, pid_t tid);
+
+/* These constants are modelled after proc(5) */
+enum {
+    VIR_PROCESS_STAT_PID,
+    VIR_PROCESS_STAT_COMM,
+    VIR_PROCESS_STAT_STATE,
+    VIR_PROCESS_STAT_PPID,
+    VIR_PROCESS_STAT_PGRP,
+    VIR_PROCESS_STAT_SESSION,
+    VIR_PROCESS_STAT_TTY_NR,
+    VIR_PROCESS_STAT_TPGID,
+    VIR_PROCESS_STAT_FLAGS,
+    VIR_PROCESS_STAT_MINFLT,
+    VIR_PROCESS_STAT_CMINFLT,
+    VIR_PROCESS_STAT_MAJFLT,
+    VIR_PROCESS_STAT_CMAJFLT,
+    VIR_PROCESS_STAT_UTIME,
+    VIR_PROCESS_STAT_STIME,
+    VIR_PROCESS_STAT_CUTIME,
+    VIR_PROCESS_STAT_CSTIME,
+    VIR_PROCESS_STAT_PRIORITY,
+    VIR_PROCESS_STAT_NICE,
+    VIR_PROCESS_STAT_NUM_THREADS,
+    VIR_PROCESS_STAT_ITREALVALUE,
+    VIR_PROCESS_STAT_STARTTIME,
+    VIR_PROCESS_STAT_VSIZE,
+    VIR_PROCESS_STAT_RSS,
+    VIR_PROCESS_STAT_RSSLIM,
+    VIR_PROCESS_STAT_STARTCODE,
+    VIR_PROCESS_STAT_ENDCODE,
+    VIR_PROCESS_STAT_STARTSTACK,
+    VIR_PROCESS_STAT_KSTKESP,
+    VIR_PROCESS_STAT_KSTKEIP,
+    VIR_PROCESS_STAT_SIGNAL,
+    VIR_PROCESS_STAT_BLOCKED,
+    VIR_PROCESS_STAT_SIGIGNORE,
+    VIR_PROCESS_STAT_SIGCATCH,
+    VIR_PROCESS_STAT_WCHAN,
+    VIR_PROCESS_STAT_NSWAP,
+    VIR_PROCESS_STAT_CNSWAP,
+    VIR_PROCESS_STAT_EXIT_SIGNAL,
+    VIR_PROCESS_STAT_PROCESSOR,
+    VIR_PROCESS_STAT_RT_PRIORITY,
+    VIR_PROCESS_STAT_POLICY,
+    VIR_PROCESS_STAT_DELAYACCT_BLKIO_TICKS,
+    VIR_PROCESS_STAT_GUEST_TIME,
+    VIR_PROCESS_STAT_CGUEST_TIME,
+    VIR_PROCESS_STAT_START_DATA,
+    VIR_PROCESS_STAT_END_DATA,
+    VIR_PROCESS_STAT_START_BRK,
+    VIR_PROCESS_STAT_ARG_START,
+    VIR_PROCESS_STAT_ARG_END,
+    VIR_PROCESS_STAT_ENV_START,
+    VIR_PROCESS_STAT_ENV_END,
+    VIR_PROCESS_STAT_EXIT_CODE,
+};
+
+/*
+ * At the time of writing there are 52 values reported in /proc/.../stat, the
+ * line below checks that the last one has the right value, increase accordingly
+ * based on proc(5) whenever adding new fields.
+*/
+G_STATIC_ASSERT(VIR_PROCESS_STAT_EXIT_CODE == 51);
+
 typedef enum {
     VIR_PROCESS_NAMESPACE_MNT = (1 << 1),
     VIR_PROCESS_NAMESPACE_IPC = (1 << 2),
