@@ -109,51 +109,47 @@ static int
 testQemuAgentFSFreeze(const void *data)
 {
     virDomainXMLOption *xmlopt = (virDomainXMLOption *)data;
-    qemuMonitorTest *test = qemuMonitorTestNewAgent(xmlopt);
+    g_autoptr(qemuMonitorTest) test = qemuMonitorTestNewAgent(xmlopt);
     const char *mountpoints[] = {"/fs1", "/fs2", "/fs3", "/fs4", "/fs5"};
-    int ret = -1;
+    int rc;
 
     if (!test)
         return -1;
 
     if (qemuMonitorTestAddAgentSyncResponse(test) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddItem(test, "guest-fsfreeze-freeze-list",
                                "{ \"return\" : 5 }") < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddAgentSyncResponse(test) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddItem(test, "guest-fsfreeze-freeze",
                                "{ \"return\" : 7 }") < 0)
-        goto cleanup;
+        return -1;
 
-    if ((ret = qemuAgentFSFreeze(qemuMonitorTestGetAgent(test),
-                                 mountpoints, 5)) < 0)
-        goto cleanup;
+    if ((rc = qemuAgentFSFreeze(qemuMonitorTestGetAgent(test),
+                                mountpoints, 5)) < 0)
+        return -1;
 
-    if (ret != 5) {
+    if (rc != 5) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
-                       "expected 5 frozen filesystems, got %d", ret);
-        goto cleanup;
+                       "expected 5 frozen filesystems, got %d", rc);
+        return -1;
     }
 
-    if ((ret = qemuAgentFSFreeze(qemuMonitorTestGetAgent(test), NULL, 0)) < 0)
-        goto cleanup;
+    if ((rc = qemuAgentFSFreeze(qemuMonitorTestGetAgent(test), NULL, 0)) < 0)
+        return -1;
 
-    if (ret != 7) {
+    if (rc != 7) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
-                       "expected 7 frozen filesystems, got %d", ret);
-        goto cleanup;
+                       "expected 7 frozen filesystems, got %d", rc);
+        return -1;
     }
 
-    ret = 0;
-
- cleanup:
-    qemuMonitorTestFree(test);
-    return ret;
+    return 0;
 }
 
 
@@ -161,49 +157,45 @@ static int
 testQemuAgentFSThaw(const void *data)
 {
     virDomainXMLOption *xmlopt = (virDomainXMLOption *)data;
-    qemuMonitorTest *test = qemuMonitorTestNewAgent(xmlopt);
-    int ret = -1;
+    g_autoptr(qemuMonitorTest) test = qemuMonitorTestNewAgent(xmlopt);
+    int rc;
 
     if (!test)
         return -1;
 
     if (qemuMonitorTestAddAgentSyncResponse(test) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddItem(test, "guest-fsfreeze-thaw",
                                "{ \"return\" : 5 }") < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddAgentSyncResponse(test) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddItem(test, "guest-fsfreeze-thaw",
                                "{ \"return\" : 7 }") < 0)
-        goto cleanup;
+        return -1;
 
-    if ((ret = qemuAgentFSThaw(qemuMonitorTestGetAgent(test))) < 0)
-        goto cleanup;
+    if ((rc = qemuAgentFSThaw(qemuMonitorTestGetAgent(test))) < 0)
+        return -1;
 
-    if (ret != 5) {
+    if (rc != 5) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
-                       "expected 5 thawed filesystems, got %d", ret);
-        goto cleanup;
+                       "expected 5 thawed filesystems, got %d", rc);
+        return -1;
     }
 
-    if ((ret = qemuAgentFSThaw(qemuMonitorTestGetAgent(test))) < 0)
-        goto cleanup;
+    if ((rc = qemuAgentFSThaw(qemuMonitorTestGetAgent(test))) < 0)
+        return -1;
 
-    if (ret != 7) {
+    if (rc != 7) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
-                       "expected 7 thawed filesystems, got %d", ret);
-        goto cleanup;
+                       "expected 7 thawed filesystems, got %d", rc);
+        return -1;
     }
 
-    ret = 0;
-
- cleanup:
-    qemuMonitorTestFree(test);
-    return ret;
+    return 0;
 }
 
 
@@ -211,29 +203,24 @@ static int
 testQemuAgentFSTrim(const void *data)
 {
     virDomainXMLOption *xmlopt = (virDomainXMLOption *)data;
-    qemuMonitorTest *test = qemuMonitorTestNewAgent(xmlopt);
-    int ret = -1;
+    g_autoptr(qemuMonitorTest) test = qemuMonitorTestNewAgent(xmlopt);
 
     if (!test)
         return -1;
 
     if (qemuMonitorTestAddAgentSyncResponse(test) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddItemParams(test, "guest-fstrim",
                                      "{ \"return\" : {} }",
                                      "minimum", "1337",
                                      NULL) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuAgentFSTrim(qemuMonitorTestGetAgent(test), 1337) < 0)
-        goto cleanup;
+        return -1;
 
-    ret = 0;
-
- cleanup:
-    qemuMonitorTestFree(test);
-    return ret;
+    return 0;
 }
 
 
@@ -242,9 +229,8 @@ testQemuAgentGetFSInfoCommon(virDomainXMLOption *xmlopt,
                              qemuMonitorTest **test,
                              virDomainDef **def)
 {
-    int ret = -1;
     g_autofree char *domain_filename = NULL;
-    qemuMonitorTest *ret_test = NULL;
+    g_autoptr(qemuMonitorTest) ret_test = NULL;
     g_autoptr(virDomainDef) ret_def = NULL;
 
     if (!test || !def)
@@ -257,10 +243,10 @@ testQemuAgentGetFSInfoCommon(virDomainXMLOption *xmlopt,
 
     if (!(ret_def = virDomainDefParseFile(domain_filename, xmlopt,
                                           NULL, VIR_DOMAIN_DEF_PARSE_INACTIVE)))
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddAgentSyncResponse(ret_test) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddItem(ret_test, "guest-get-fsinfo",
                                "{\"return\": ["
@@ -296,23 +282,18 @@ testQemuAgentGetFSInfoCommon(virDomainXMLOption *xmlopt,
                                "  {\"name\": \"sdb1\","
                                "   \"mountpoint\": \"/mnt/disk\","
                                "   \"disk\": [], \"type\": \"xfs\"}]}") < 0)
-                               goto cleanup;
+                               return -1;
 
     *test = g_steal_pointer(&ret_test);
     *def = g_steal_pointer(&ret_def);
-    ret = 0;
-
- cleanup:
-    if (ret_test)
-        qemuMonitorTestFree(ret_test);
-    return ret;
+    return 0;
 }
 
 static int
 testQemuAgentGetFSInfo(const void *data)
 {
     virDomainXMLOption *xmlopt = (virDomainXMLOption *)data;
-    qemuMonitorTest *test = NULL;
+    g_autoptr(qemuMonitorTest) test = NULL;
     g_autoptr(virDomainDef) def = NULL;
     qemuAgentFSInfo **info = NULL;
     int ret = -1, ninfo = 0, i;
@@ -405,7 +386,6 @@ testQemuAgentGetFSInfo(const void *data)
     for (i = 0; i < ninfo; i++)
         qemuAgentFSInfoFree(info[i]);
     VIR_FREE(info);
-    qemuMonitorTestFree(test);
     return ret;
 }
 
@@ -413,45 +393,40 @@ static int
 testQemuAgentSuspend(const void *data)
 {
     virDomainXMLOption *xmlopt = (virDomainXMLOption *)data;
-    qemuMonitorTest *test = qemuMonitorTestNewAgent(xmlopt);
-    int ret = -1;
+    g_autoptr(qemuMonitorTest) test = qemuMonitorTestNewAgent(xmlopt);
     size_t i;
 
     if (!test)
         return -1;
 
     if (qemuMonitorTestAddAgentSyncResponse(test) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddItem(test, "guest-suspend-ram",
                                "{ \"return\" : {} }") < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddAgentSyncResponse(test) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddItem(test, "guest-suspend-disk",
                                "{ \"return\" : {} }") < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddAgentSyncResponse(test) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddItem(test, "guest-suspend-hybrid",
                                "{ \"return\" : {} }") < 0)
-        goto cleanup;
+        return -1;
 
     /* try the commands - fail if ordering changes */
     for (i = 0; i < VIR_NODE_SUSPEND_TARGET_LAST; i++) {
         if (qemuAgentSuspend(qemuMonitorTestGetAgent(test), i) < 0)
-            goto cleanup;
+            return -1;
     }
 
-    ret = 0;
-
- cleanup:
-    qemuMonitorTestFree(test);
-    return ret;
+    return 0;
 }
 
 
@@ -511,15 +486,14 @@ static int
 testQemuAgentShutdown(const void *data)
 {
     virDomainXMLOption *xmlopt = (virDomainXMLOption *)data;
-    qemuMonitorTest *test = qemuMonitorTestNewAgent(xmlopt);
+    g_autoptr(qemuMonitorTest) test = qemuMonitorTestNewAgent(xmlopt);
     struct qemuAgentShutdownTestData priv;
-    int ret = -1;
 
     if (!test)
         return -1;
 
     if (qemuMonitorTestAddAgentSyncResponse(test) < 0)
-        goto cleanup;
+        return -1;
 
     priv.event = QEMU_AGENT_EVENT_SHUTDOWN;
     priv.mode = "halt";
@@ -527,14 +501,14 @@ testQemuAgentShutdown(const void *data)
     if (qemuMonitorTestAddHandler(test, "guest-shutdown",
                                   qemuAgentShutdownTestMonitorHandler,
                                   &priv, NULL) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuAgentShutdown(qemuMonitorTestGetAgent(test),
                           QEMU_AGENT_SHUTDOWN_HALT) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddAgentSyncResponse(test) < 0)
-        goto cleanup;
+        return -1;
 
     priv.event = QEMU_AGENT_EVENT_SHUTDOWN;
     priv.mode = "powerdown";
@@ -542,14 +516,14 @@ testQemuAgentShutdown(const void *data)
     if (qemuMonitorTestAddHandler(test, "guest-shutdown",
                                   qemuAgentShutdownTestMonitorHandler,
                                   &priv, NULL) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuAgentShutdown(qemuMonitorTestGetAgent(test),
                           QEMU_AGENT_SHUTDOWN_POWERDOWN) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddAgentSyncResponse(test) < 0)
-        goto cleanup;
+        return -1;
 
     priv.event = QEMU_AGENT_EVENT_RESET;
     priv.mode = "reboot";
@@ -558,17 +532,17 @@ testQemuAgentShutdown(const void *data)
                                   "guest-shutdown",
                                   qemuAgentShutdownTestMonitorHandler,
                                   &priv, NULL) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuAgentShutdown(qemuMonitorTestGetAgent(test),
                           QEMU_AGENT_SHUTDOWN_REBOOT) < 0)
-        goto cleanup;
+        return -1;
 
     /* check negative response, so that we can verify that the agent breaks
      * out from sleep */
 
     if (qemuMonitorTestAddAgentSyncResponse(test) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddItem(test, "guest-shutdown",
                                "{\"error\":"
@@ -578,20 +552,16 @@ testQemuAgentShutdown(const void *data)
                                "     \"data\":{\"name\":\"guest-shutdown\"}"
                                "    }"
                                "}") < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuAgentShutdown(qemuMonitorTestGetAgent(test),
                           QEMU_AGENT_SHUTDOWN_REBOOT) != -1) {
         virReportError(VIR_ERR_INTERNAL_ERROR, "%s",
                        "agent shutdown command should have failed");
-        goto cleanup;
+        return -1;
     }
 
-    ret = 0;
-
- cleanup:
-    qemuMonitorTestFree(test);
-    return ret;
+    return 0;
 }
 
 
@@ -631,80 +601,74 @@ static int
 testQemuAgentCPU(const void *data)
 {
     virDomainXMLOption *xmlopt = (virDomainXMLOption *)data;
-    qemuMonitorTest *test = qemuMonitorTestNewAgent(xmlopt);
-    qemuAgentCPUInfo *cpuinfo = NULL;
+    g_autoptr(qemuMonitorTest) test = qemuMonitorTestNewAgent(xmlopt);
+    g_autofree qemuAgentCPUInfo *cpuinfo = NULL;
     int nvcpus;
-    int ret = -1;
 
     if (!test)
         return -1;
 
     if (qemuMonitorTestAddAgentSyncResponse(test) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddItem(test, "guest-get-vcpus",
                                testQemuAgentCPUResponse) < 0)
-        goto cleanup;
+        return -1;
 
     /* get cpus */
     if ((nvcpus = qemuAgentGetVCPUs(qemuMonitorTestGetAgent(test),
                                     &cpuinfo)) < 0)
-        goto cleanup;
+        return -1;
 
     if (nvcpus != 4) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
                        "Expected '4' cpus, got '%d'", nvcpus);
-        goto cleanup;
+        return -1;
     }
 
     /* try to unplug one */
     if (qemuAgentUpdateCPUInfo(2, cpuinfo, nvcpus) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddAgentSyncResponse(test) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddItemParams(test, "guest-set-vcpus",
                                      "{ \"return\" : 1 }",
                                      "vcpus", testQemuAgentCPUArguments1,
                                      NULL) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuAgentSetVCPUs(qemuMonitorTestGetAgent(test), cpuinfo, nvcpus) < 0)
-        goto cleanup;
+        return -1;
 
     /* try to hotplug two, second one will fail */
     if (qemuMonitorTestAddAgentSyncResponse(test) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddItemParams(test, "guest-set-vcpus",
                                      "{ \"return\" : 1 }",
                                      "vcpus", testQemuAgentCPUArguments2,
                                      NULL) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddAgentSyncResponse(test) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddItemParams(test, "guest-set-vcpus",
                                      "{ \"error\" : \"random error\" }",
                                      "vcpus", testQemuAgentCPUArguments3,
                                      NULL) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuAgentUpdateCPUInfo(4, cpuinfo, nvcpus) < 0)
-        goto cleanup;
+        return -1;
 
     /* this should fail */
     if (qemuAgentSetVCPUs(qemuMonitorTestGetAgent(test), cpuinfo, nvcpus) != -1)
-        goto cleanup;
+        return -1;
 
-    ret = 0;
-
- cleanup:
-    VIR_FREE(cpuinfo);
-    qemuMonitorTestFree(test);
-    return ret;
+    return 0;
 }
 
 
@@ -715,39 +679,34 @@ static int
 testQemuAgentArbitraryCommand(const void *data)
 {
     virDomainXMLOption *xmlopt = (virDomainXMLOption *)data;
-    qemuMonitorTest *test = qemuMonitorTestNewAgent(xmlopt);
-    int ret = -1;
+    g_autoptr(qemuMonitorTest) test = qemuMonitorTestNewAgent(xmlopt);
     g_autofree char *reply = NULL;
 
     if (!test)
         return -1;
 
     if (qemuMonitorTestAddAgentSyncResponse(test) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddItem(test, "ble",
                                testQemuAgentArbitraryCommandResponse) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuAgentArbitraryCommand(qemuMonitorTestGetAgent(test),
                                   "{\"execute\":\"ble\"}",
                                   &reply,
                                   VIR_DOMAIN_QEMU_AGENT_COMMAND_BLOCK) < 0)
-        goto cleanup;
+        return -1;
 
     if (STRNEQ(reply, testQemuAgentArbitraryCommandResponse)) {
         virReportError(VIR_ERR_INTERNAL_ERROR,
                        "invalid processing of guest agent reply: "
                        "got '%s' expected '%s'",
                        reply, testQemuAgentArbitraryCommandResponse);
-        goto cleanup;
+        return -1;
     }
 
-    ret = 0;
-
- cleanup:
-    qemuMonitorTestFree(test);
-    return ret;
+    return 0;
 }
 
 
@@ -764,38 +723,35 @@ static int
 testQemuAgentTimeout(const void *data)
 {
     virDomainXMLOption *xmlopt = (virDomainXMLOption *)data;
-    qemuMonitorTest *test = qemuMonitorTestNewAgent(xmlopt);
+    g_autoptr(qemuMonitorTest) test = qemuMonitorTestNewAgent(xmlopt);
     g_autofree char *reply = NULL;
-    int ret = -1;
 
     if (!test)
         return -1;
 
-    if (virTestGetExpensive() == 0) {
-        ret = EXIT_AM_SKIP;
-        goto cleanup;
-    }
+    if (virTestGetExpensive() == 0)
+        return EXIT_AM_SKIP;
 
     if (qemuMonitorTestAddHandler(test, NULL,
                                   qemuAgentTimeoutTestMonitorHandler,
                                   NULL, NULL) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuAgentFSFreeze(qemuMonitorTestGetAgent(test), NULL, 0) != -1) {
         virReportError(VIR_ERR_INTERNAL_ERROR, "%s",
                        "agent command should have failed");
-        goto cleanup;
+        return -1;
     }
 
     /* test timeout */
     if (qemuMonitorTestAddAgentSyncResponse(test) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuMonitorTestAddHandler(test,
                                   NULL,
                                   qemuAgentTimeoutTestMonitorHandler,
                                   NULL, NULL) < 0)
-        goto cleanup;
+        return -1;
 
     if (qemuAgentArbitraryCommand(qemuMonitorTestGetAgent(test),
                                   "{\"execute\":\"ble\"}",
@@ -803,14 +759,10 @@ testQemuAgentTimeout(const void *data)
                                   1) != -2) {
         virReportError(VIR_ERR_INTERNAL_ERROR, "%s",
                        "agent command didn't time out");
-        goto cleanup;
+        return -1;
     }
 
-    ret = 0;
-
- cleanup:
-    qemuMonitorTestFree(test);
-    return ret;
+    return 0;
 }
 
 static const char testQemuAgentGetInterfacesResponse[] =
@@ -890,7 +842,7 @@ static int
 testQemuAgentGetInterfaces(const void *data)
 {
     virDomainXMLOption *xmlopt = (virDomainXMLOption *)data;
-    qemuMonitorTest *test = qemuMonitorTestNewAgent(xmlopt);
+    g_autoptr(qemuMonitorTest) test = qemuMonitorTestNewAgent(xmlopt);
     size_t i;
     int ret = -1;
     int ifaces_count = 0;
@@ -907,7 +859,7 @@ testQemuAgentGetInterfaces(const void *data)
         goto cleanup;
 
     if ((ifaces_count = qemuAgentGetInterfaces(qemuMonitorTestGetAgent(test),
-                                               &ifaces)) < 0)
+                                               &ifaces, true)) < 0)
         goto cleanup;
 
     if (ifaces_count != 4) {
@@ -991,7 +943,6 @@ testQemuAgentGetInterfaces(const void *data)
     ret = 0;
 
  cleanup:
-    qemuMonitorTestFree(test);
     if (ifaces) {
         for (i = 0; i < ifaces_count; i++)
             virDomainInterfaceFree(ifaces[i]);
@@ -1039,7 +990,7 @@ static int
 testQemuAgentGetDisks(const void *data)
 {
     virDomainXMLOption *xmlopt = (virDomainXMLOption *)data;
-    qemuMonitorTest *test = qemuMonitorTestNewAgent(xmlopt);
+    g_autoptr(qemuMonitorTest) test = qemuMonitorTestNewAgent(xmlopt);
     size_t i;
     int ret = -1;
     int disks_count = 0;
@@ -1100,7 +1051,6 @@ testQemuAgentGetDisks(const void *data)
     ret = 0;
 
  cleanup:
-    qemuMonitorTestFree(test);
     if (disks) {
         for (i = 0; i < disks_count; i++)
             qemuAgentDiskInfoFree(disks[i]);
@@ -1189,7 +1139,7 @@ static int
 testQemuAgentUsers(const void *data)
 {
     virDomainXMLOption *xmlopt = (virDomainXMLOption *)data;
-    qemuMonitorTest *test = qemuMonitorTestNewAgent(xmlopt);
+    g_autoptr(qemuMonitorTest) test = qemuMonitorTestNewAgent(xmlopt);
     virTypedParameterPtr params = NULL;
     int nparams = 0;
     int maxparams = 0;
@@ -1255,7 +1205,6 @@ testQemuAgentUsers(const void *data)
 
  cleanup:
     virTypedParamsFree(params, nparams);
-    qemuMonitorTestFree(test);
     return ret;
 }
 
@@ -1289,7 +1238,7 @@ static int
 testQemuAgentOSInfo(const void *data)
 {
     virDomainXMLOption *xmlopt = (virDomainXMLOption *)data;
-    qemuMonitorTest *test = qemuMonitorTestNewAgent(xmlopt);
+    g_autoptr(qemuMonitorTest) test = qemuMonitorTestNewAgent(xmlopt);
     virTypedParameterPtr params = NULL;
     int nparams = 0;
     int maxparams = 0;
@@ -1371,12 +1320,11 @@ testQemuAgentOSInfo(const void *data)
     VALIDATE_PARAM("os.kernel-release", "7601");
     VALIDATE_PARAM("os.kernel-version", "6.1");
     VALIDATE_PARAM("os.machine", "x86_64");
-    virTypedParamsFree(params, nparams);
 
     ret = 0;
 
  cleanup:
-    qemuMonitorTestFree(test);
+    virTypedParamsFree(params, nparams);
     return ret;
 }
 
@@ -1393,7 +1341,9 @@ static int
 testQemuAgentTimezone(const void *data)
 {
     virDomainXMLOption *xmlopt = (virDomainXMLOption *)data;
-    qemuMonitorTest *test = qemuMonitorTestNewAgent(xmlopt);
+    g_autoptr(qemuMonitorTest) test = qemuMonitorTestNewAgent(xmlopt);
+    virTypedParameterPtr params = NULL;
+    int nparams = 0;
     int ret = -1;
 
     if (!test)
@@ -1401,8 +1351,6 @@ testQemuAgentTimezone(const void *data)
 
 #define VALIDATE_TIMEZONE(response_, expected_name_, expected_offset_) \
     do { \
-        virTypedParameterPtr params_ = NULL; \
-        int nparams_ = 0; \
         int maxparams_ = 0; \
         const char *name_ = NULL; \
         int offset_; \
@@ -1411,15 +1359,18 @@ testQemuAgentTimezone(const void *data)
         if (qemuMonitorTestAddItem(test, "guest-get-timezone", \
                                    response_) < 0) \
             goto cleanup; \
+        virTypedParamsFree(params, nparams); \
+        params = NULL; \
+        nparams = 0; \
         if (qemuAgentGetTimezone(qemuMonitorTestGetAgent(test), \
-                                 &params_, &nparams_, &maxparams_, true) < 0) \
+                                 &params, &nparams, &maxparams_, true) < 0) \
             goto cleanup; \
-        if (nparams_ != 2) { \
+        if (nparams != 2) { \
             virReportError(VIR_ERR_INTERNAL_ERROR, \
-                           "Expected 2 params, got %d", nparams_); \
+                           "Expected 2 params, got %d", nparams); \
             goto cleanup; \
         } \
-        if (virTypedParamsGetString(params_, nparams_, \
+        if (virTypedParamsGetString(params, nparams, \
                                     "timezone.name", &name_) < 0) { \
             virReportError(VIR_ERR_INTERNAL_ERROR, "missing param '%s'", \
                            "tiemzone.name"); \
@@ -1430,7 +1381,7 @@ testQemuAgentTimezone(const void *data)
                            "Expected name '%s', got '%s'", expected_name_, name_); \
             goto cleanup; \
         } \
-        if (virTypedParamsGetInt(params_, nparams_, \
+        if (virTypedParamsGetInt(params, nparams, \
                                  "timezone.offset", &offset_) < 0) { \
             virReportError(VIR_ERR_INTERNAL_ERROR, "missing param '%s'", \
                            "tiemzone.offset"); \
@@ -1442,7 +1393,6 @@ testQemuAgentTimezone(const void *data)
                            expected_offset_); \
             goto cleanup; \
         } \
-        virTypedParamsFree(params_, nparams_); \
     } while (0)
 
     VALIDATE_TIMEZONE(testQemuAgentTimezoneResponse1, "IST", 19800);
@@ -1453,7 +1403,7 @@ testQemuAgentTimezone(const void *data)
     ret = 0;
 
  cleanup:
-    qemuMonitorTestFree(test);
+    virTypedParamsFree(params, nparams);
     return ret;
 }
 static int
