@@ -996,9 +996,9 @@ qemuMonitorCommonTestNew(virDomainXMLOption *xmlopt,
                          virDomainObj *vm,
                          virDomainChrSourceDef *src)
 {
-    qemuMonitorTest *test = NULL;
-    char *path = NULL;
-    char *tmpdir_template = NULL;
+    g_autoptr(qemuMonitorTest) test = NULL;
+    g_autofree char *path = NULL;
+    g_autofree char *tmpdir_template = NULL;
 
     test = g_new0(qemuMonitorTest, 1);
 
@@ -1014,7 +1014,7 @@ qemuMonitorCommonTestNew(virDomainXMLOption *xmlopt,
     if (!(test->tmpdir = g_mkdtemp(tmpdir_template))) {
         virReportSystemError(errno, "%s",
                              "Failed to create temporary directory");
-        goto error;
+        return NULL;
     }
 
     tmpdir_template = NULL;
@@ -1026,14 +1026,14 @@ qemuMonitorCommonTestNew(virDomainXMLOption *xmlopt,
     } else {
         test->vm = virDomainObjNew(xmlopt);
         if (!test->vm)
-            goto error;
+            return NULL;
         if (!(test->vm->def = virDomainDefNew(xmlopt)))
-            goto error;
+            return NULL;
     }
 
     if (virNetSocketNewListenUNIX(path, 0700, geteuid(), getegid(),
                                   &test->server) < 0)
-        goto error;
+        return NULL;
 
     memset(src, 0, sizeof(*src));
     src->type = VIR_DOMAIN_CHR_TYPE_UNIX;
@@ -1042,16 +1042,9 @@ qemuMonitorCommonTestNew(virDomainXMLOption *xmlopt,
     path = NULL;
 
     if (virNetSocketListen(test->server, 1) < 0)
-        goto error;
-
-    return test;
-
- error:
-    VIR_FREE(path);
-    VIR_FREE(tmpdir_template);
-    qemuMonitorTestFree(test);
-    return NULL;
+        return NULL;
 
+    return g_steal_pointer(&test);
 }
 
 
@@ -1116,7 +1109,7 @@ qemuMonitorTestNew(virDomainXMLOption *xmlopt,
                    const char *greeting,
                    GHashTable *schema)
 {
-    qemuMonitorTest *test = NULL;
+    g_autoptr(qemuMonitorTest) test = NULL;
     virDomainChrSourceDef src;
 
     memset(&src, 0, sizeof(src));
@@ -1150,11 +1143,10 @@ qemuMonitorTestNew(virDomainXMLOption *xmlopt,
 
     virDomainChrSourceDefClear(&src);
 
-    return test;
+    return g_steal_pointer(&test);
 
  error:
     virDomainChrSourceDefClear(&src);
-    qemuMonitorTestFree(test);
     return NULL;
 }
 
@@ -1177,7 +1169,7 @@ qemuMonitorTestNewFromFile(const char *fileName,
                            virDomainXMLOption *xmlopt,
                            bool simple)
 {
-    qemuMonitorTest *test = NULL;
+    g_autoptr(qemuMonitorTest) test = NULL;
     g_autofree char *json = NULL;
     char *tmp;
     char *singleReply;
@@ -1204,12 +1196,12 @@ qemuMonitorTestNewFromFile(const char *fileName,
 
             if (test) {
                 if (qemuMonitorTestAddItem(test, NULL, singleReply) < 0)
-                    goto error;
+                    return NULL;
             } else {
                 /* Create new mocked monitor with our greeting */
                 if (!(test = qemuMonitorTestNew(xmlopt, NULL, NULL,
                                                 singleReply, NULL)))
-                    goto error;
+                    return NULL;
             }
 
             if (!eof) {
@@ -1224,13 +1216,9 @@ qemuMonitorTestNewFromFile(const char *fileName,
     }
 
     if (test && qemuMonitorTestAddItem(test, NULL, singleReply) < 0)
-        goto error;
+        return NULL;
 
-    return test;
-
- error:
-    qemuMonitorTestFree(test);
-    return NULL;
+    return g_steal_pointer(&test);
 }
 
 
@@ -1311,7 +1299,7 @@ qemuMonitorTestNewFromFileFull(const char *fileName,
                                virDomainObj *vm,
                                GHashTable *qmpschema)
 {
-    qemuMonitorTest *ret = NULL;
+    g_autoptr(qemuMonitorTest) ret = NULL;
     g_autofree char *jsonstr = NULL;
     char *tmp;
     size_t line = 0;
@@ -1349,7 +1337,7 @@ qemuMonitorTestNewFromFileFull(const char *fileName,
         if (response) {
             if (qemuMonitorTestFullAddItem(ret, fileName, command,
                                            response, commandln) < 0)
-                goto error;
+                return NULL;
             command = NULL;
             response = NULL;
         }
@@ -1369,26 +1357,22 @@ qemuMonitorTestNewFromFileFull(const char *fileName,
         if (!response) {
             virReportError(VIR_ERR_INTERNAL_ERROR, "missing response for command "
                            "on line '%zu' in '%s'", commandln, fileName);
-            goto error;
+            return NULL;
         }
 
         if (qemuMonitorTestFullAddItem(ret, fileName, command,
                                        response, commandln) < 0)
-            goto error;
+            return NULL;
     }
 
-    return ret;
-
- error:
-    qemuMonitorTestFree(ret);
-    return NULL;
+    return g_steal_pointer(&ret);
 }
 
 
 qemuMonitorTest *
 qemuMonitorTestNewAgent(virDomainXMLOption *xmlopt)
 {
-    qemuMonitorTest *test = NULL;
+    g_autoptr(qemuMonitorTest) test = NULL;
     virDomainChrSourceDef src;
 
     memset(&src, 0, sizeof(src));
@@ -1413,11 +1397,10 @@ qemuMonitorTestNewAgent(virDomainXMLOption *xmlopt)
 
     virDomainChrSourceDefClear(&src);
 
-    return test;
+    return g_steal_pointer(&test);
 
  error:
     virDomainChrSourceDefClear(&src);
-    qemuMonitorTestFree(test);
     return NULL;
 }
 
